@@ -18,8 +18,8 @@ def img_to_fobj(img, format, autoconvert=True, **options):
 
 
 def open_image(target):
-    target.seek(0)
-    return Image.open(target)
+    buffer = StringIO(target.read())
+    return Image.open(buffer)
 
 
 _pil_init = 0
@@ -264,6 +264,7 @@ def prepare_image(img, format):
     """
     make_opaque = False
     save_kwargs = {}
+    format = format.upper()
 
     if img.mode == 'RGBA':
         if format in RGBA_TRANSPARENCY_FORMATS:
